yakumo.mapper.Dict

Package yakumo :: Module mapper :: Class Dict |
[hide private]
[frames] | no frames]

# Class Dict

source code

    object --+
             |
            Dict

Instance Methods | [hide private]
__init__(self, mappers) x.__init__(...) initializes x; see help(type(x)) for signature | source code
to_attr(self, manager_class, attr, do_raise=False) | source code
to_json(self, manager_class, attr) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| mappers = `None`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, mappers) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)